import { Controller, PureEventDispatcher } from '@a11d/lit';
export class PointerTypeController extends Controller {
    static get type() { return this._type ?? (window.matchMedia('(pointer: coarse)').matches ? 'touch' : 'mouse'); }
    static set type(value) {
        if (this._type !== value) {
            this._type = value;
            this.change.dispatch(value);
        }
    }
    constructor(host, options) {
        super(host);
        this.host = host;
        this.options = options;
        this.handleChange = (type) => {
            this.options?.handleTypeChange?.(type);
            this.host.requestUpdate();
        };
    }
    get type() { return PointerTypeController.type; }
    hostConnected() {
        PointerTypeController.change.subscribe(this.handleChange);
    }
    hostDisconnected() {
        PointerTypeController.change.unsubscribe(this.handleChange);
    }
}
PointerTypeController.change = new PureEventDispatcher();
(() => {
    for (const event of ['pointerdown', 'pointermove', 'pointerup', 'pointercancel']) {
        document?.addEventListener(event, (e) => {
            switch (e.pointerType) {
                case 2:
                case 'touch':
                    PointerTypeController.type = 'touch';
                    break;
                case 3:
                case 'pen':
                    PointerTypeController.type = 'pen';
                    break;
                default:
                    PointerTypeController.type = 'mouse';
                    break;
            }
        }, { passive: true });
    }
})();
